@@ -32,15 +32,17 @@
 
 """|UDM| allocators to allocate and lock resources for |LDAP| object creation."""
 
+from logging import getLogger
+
 import ldap
 from ldap.filter import filter_format
 
 import univention.admin.locking
 import univention.admin.uexceptions
-import univention.debug as ud
 from univention.admin import configRegistry, localization
 
 
+log = getLogger('ADMIN')
 translation = localization.translation('univention/admin')
 _ = translation.translate
 
@@ -85,7 +87,7 @@ def requestUserSid(lo, position, uid_s):
     domainsid = searchResult[0][1]['sambaSID'][0].decode('ASCII')
     sid = domainsid + '-' + rid
 
-    ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: request user sid. SID = %s-%s' % (domainsid, rid))
+    log.debug('ALLOCATE: request user sid. SID = %s-%s', domainsid, rid)
 
     return request(lo, position, 'sid', sid)
 
@@ -106,14 +108,14 @@ def requestGroupSid(lo, position, gid_s, generateDomainLocalSid=False):
 
 
 def acquireRange(lo, position, atype, attr, ranges, scope='base'):
-    ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Start allocation for type = %r' % atype)
+    log.debug('ALLOCATE: Start allocation for type = %r', atype)
     startID = lo.getAttr('cn=%s,cn=temporary,cn=univention,%s' % (ldap.dn.escape_dn_chars(atype), position.getBase()), 'univentionLastUsedValue')
 
-    ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Start ID = %r' % startID)
+    log.debug('ALLOCATE: Start ID = %r', startID)
 
     if not startID:
         startID = ranges[0]['first']
-        ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Set Start ID to first %r' % startID)
+        log.debug('ALLOCATE: Set Start ID to first %r', startID)
     else:
         startID = int(startID[0])
 
@@ -125,40 +127,40 @@ def acquireRange(lo, position, atype, attr, ranges, scope='base'):
 
         while startID < last:
             startID += 1
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Set Start ID %r' % startID)
+            log.debug('ALLOCATE: Set Start ID %r', startID)
             try:
                 if other:
                     # exception occurred while locking other, so atype was successfully locked and must be released
                     univention.admin.locking.unlock(lo, position, atype, str(startID - 1).encode('utf-8'), scope=scope)
                     other = None
-                ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Lock ID %r for %r' % (startID, atype))
+                log.debug('ALLOCATE: Lock ID %r for %r', startID, atype)
                 univention.admin.locking.lock(lo, position, atype, str(startID).encode('utf-8'), scope=scope)
                 if atype in ('uidNumber', 'gidNumber'):
                     # reserve the same ID for both
                     other = 'uidNumber' if atype == 'gidNumber' else 'gidNumber'
-                    ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Lock ID %r for %r' % (startID, other))
+                    log.debug('ALLOCATE: Lock ID %r for %r', startID, other)
                     univention.admin.locking.lock(lo, position, other, str(startID).encode('utf-8'), scope=scope)
             except univention.admin.uexceptions.noLock:
-                ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Cannot Lock ID %r' % startID)
+                log.debug('ALLOCATE: Cannot Lock ID %r', startID)
                 continue
             except univention.admin.uexceptions.objectExists:
-                ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Cannot Lock existing ID %r' % startID)
+                log.debug('ALLOCATE: Cannot Lock existing ID %r', startID)
                 continue
 
             if atype in ('uidNumber', 'gidNumber'):
                 _filter = filter_format('(|(uidNumber=%s)(gidNumber=%s))', (str(startID), str(startID)))
             else:
                 _filter = '(%s=%d)' % (attr, startID)
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: searchfor %r' % _filter)
+            log.debug('ALLOCATE: searchfor %r', _filter)
             if lo.searchDn(base=position.getBase(), filter=_filter):
-                ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Already used ID %r' % startID)
+                log.debug('ALLOCATE: Already used ID %r', startID)
                 univention.admin.locking.unlock(lo, position, atype, str(startID).encode('utf-8'), scope=scope)
                 if other:
                     univention.admin.locking.unlock(lo, position, other, str(startID).encode('utf-8'), scope=scope)
                     other = None
                 continue
 
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE: Return ID %r' % startID)
+            log.debug('ALLOCATE: Return ID %r', startID)
             if other:
                 univention.admin.locking.unlock(lo, position, other, str(startID).encode('utf-8'), scope=scope)
             return str(startID)
@@ -167,7 +169,7 @@ def acquireRange(lo, position, atype, attr, ranges, scope='base'):
 
 
 def acquireUnique(lo, position, type, value, attr, scope='base'):
-    ud.debug(ud.ADMIN, ud.INFO, 'LOCK acquireUnique scope = %s' % scope)
+    log.debug('LOCK acquireUnique scope = %s', scope)
     searchBase = position.getDomain() if scope == "domain" else position.getBase()
 
     if type == "aRecord":  # uniqueness is only relevant among hosts (one or more dns entries having the same aRecord as a host are allowed)
@@ -177,12 +179,12 @@ def acquireUnique(lo, position, type, value, attr, scope='base'):
     elif type in ['groupName', 'uid'] and configRegistry.is_true('directory/manager/user_group/uniqueness', True):
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
         if not lo.searchDn(base=searchBase, filter=filter_format('(|(&(cn=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))(uid=%s))', (value, value))):
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE return %s' % value)
+            log.debug('ALLOCATE return %s', value)
             return value
     elif type == "groupName":  # search filter is more complex then in general case
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
         if not lo.searchDn(base=searchBase, filter=filter_format('(&(%s=%s)(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping)(objectClass=posixGroup)))', (attr, value))):
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE return %s' % value)
+            log.debug('ALLOCATE return %s', value)
             return value
     elif type == 'cn-uid-position':
         base = lo.parentDn(value)
@@ -196,19 +198,19 @@ def acquireUnique(lo, position, type, value, attr, scope='base'):
             return value
         raise univention.admin.uexceptions.alreadyUsedInSubtree('name=%r position=%r' % (value, base))
     elif type in ('mailPrimaryAddress', 'mailAlternativeAddress') and configRegistry.is_true('directory/manager/mail-address/uniqueness'):
-        ud.debug(ud.ADMIN, ud.INFO, 'LOCK univention.admin.locking.lock scope = %s' % scope)
+        log.debug('LOCK univention.admin.locking.lock scope = %s', scope)
         univention.admin.locking.lock(lo, position, 'mailPrimaryAddress', value.encode('utf-8'), scope=scope)
         other = 'mailPrimaryAddress' if type == 'mailAlternativeAddress' else 'mailAlternativeAddress'
         if not lo.searchDn(base=searchBase, filter=filter_format('(|(%s=%s)(%s=%s))', (attr, value, other, value))):
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE return %s' % value)
+            log.debug('ALLOCATE return %s', value)
             return value
     elif type == 'mailAlternativeAddress':
         return value  # lock for mailAlternativeAddress exists only if above UCR variable is enabled
     else:
-        ud.debug(ud.ADMIN, ud.INFO, 'LOCK univention.admin.locking.lock scope = %s' % scope)
+        log.debug('LOCK univention.admin.locking.lock scope = %s', scope)
         univention.admin.locking.lock(lo, position, type, value.encode('utf-8'), scope=scope)
         if not lo.searchDn(base=searchBase, filter=filter_format('%s=%s', (attr, value))):
-            ud.debug(ud.ADMIN, ud.INFO, 'ALLOCATE return %s' % value)
+            log.debug('ALLOCATE return %s', value)
             return value
 
     raise univention.admin.uexceptions.noLock(_('The attribute %r could not get locked.') % (type,))
