@@ -35,11 +35,10 @@
 import io
 import os
 import sys
-import traceback
 import warnings
+from logging import getLogger
 from typing import TYPE_CHECKING, Any, List, Tuple, Union  # noqa: F401
 
-import univention.debug as ud
 from univention.admin import localization
 
 
@@ -50,6 +49,8 @@ if TYPE_CHECKING:
     _Mod3 = Tuple[str, List[str], List[str]]
     ModList = List[Union[_Mod2, _Mod3]]
 
+log = getLogger('ADMIN')
+
 translation = localization.translation('univention/admin')
 _ = translation.translate
 
@@ -65,10 +66,9 @@ def import_hook_files():
                 try:
                     with io.open(fn, 'rb') as fd:
                         exec(fd.read(), sys.modules[__name__].__dict__)  # noqa: S102
-                    ud.debug(ud.ADMIN, ud.INFO, 'admin.hook.import_hook_files: importing %r' % (fn,))
+                    log.debug('admin.hook.import_hook_files: importing %r', fn)
                 except Exception:
-                    ud.debug(ud.ADMIN, ud.ERROR, 'admin.hook.import_hook_files: loading %r failed' % (fn,))
-                    ud.debug(ud.ADMIN, ud.ERROR, 'admin.hook.import_hook_files: TRACEBACK:\n%s' % traceback.format_exc())
+                    log.exception('admin.hook.import_hook_files: loading %r failed', fn)
 
 
 class simpleHook(object):
@@ -88,7 +88,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _open called')
+        log.debug('admin.syntax.hook.simpleHook: _open called')
 
     def hook_ldap_pre_create(self, obj):
         # type: (univention.admin.handlers.simpleLdap) -> None
@@ -98,7 +98,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_pre_create called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_pre_create called')
 
     def hook_ldap_addlist(self, obj, al=[]):
         # type: (univention.admin.handlers.simpleLdap, AddList) -> AddList
@@ -111,7 +111,7 @@ class simpleHook(object):
         :param al: A list of two-tuples (ldap-attribute-name, list-of-values) which will be used to create the LDAP object.
         :returns: The (modified) add-list.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_addlist called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_addlist called')
         return al
 
     def hook_ldap_post_create(self, obj):
@@ -121,7 +121,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_post_create called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_post_create called')
 
     def hook_ldap_pre_modify(self, obj):
         # type: (univention.admin.handlers.simpleLdap) -> None
@@ -131,7 +131,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_pre_modify called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_pre_modify called')
 
     def hook_ldap_modlist(self, obj, ml=[]):
         # type: (univention.admin.handlers.simpleLdap, ModList) -> ModList
@@ -142,7 +142,7 @@ class simpleHook(object):
         :param ml: A list of tuples, which are either two-tuples (ldap-attribute-name, list-of-new-values) or three-tuples (ldap-attribute-name, list-of-old-values, list-of-new-values). It will be used to create or modify the |LDAP| object.
         :returns: The (modified) modification-list.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_modlist called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_modlist called')
         return ml
 
     def hook_ldap_post_modify(self, obj):
@@ -152,7 +152,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_post_modify called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_post_modify called')
 
     def hook_ldap_pre_remove(self, obj):
         # type: (univention.admin.handlers.simpleLdap) -> None
@@ -161,7 +161,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_pre_remove called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_pre_remove called')
 
     def hook_ldap_post_remove(self, obj):
         # type: (univention.admin.handlers.simpleLdap) -> None
@@ -170,7 +170,7 @@ class simpleHook(object):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.simpleHook: _ldap_post_remove called')
+        log.debug('admin.syntax.hook.simpleHook: _ldap_post_remove called')
 
 
 class AttributeHook(simpleHook):
@@ -201,13 +201,13 @@ class AttributeHook(simpleHook):
 
         :param obj: The |UDM| object instance.
         """
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.AttributeHook: Mapping %s (LDAP) -> %s (UDM)' % (self.ldap_attribute_name, self.udm_attribute_name))
+        log.debug('admin.syntax.hook.AttributeHook: Mapping %s (LDAP) -> %s (UDM)', self.ldap_attribute_name, self.udm_attribute_name)
         old_value = obj.oldattr.get(self.ldap_attribute_name, [])
         if self.version < 2:  # TODO: remove in UCS 5.1
             warnings.warn('Still using deprecated AttributeHook.version == 1', DeprecationWarning, stacklevel=2)
             old_value = obj[self.udm_attribute_name]
         new_value = self.map_attribute_value_to_udm(old_value)
-        ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.AttributeHook: Setting UDM value from %r to %r' % (old_value, new_value))
+        log.debug('admin.syntax.hook.AttributeHook: Setting UDM value from %r to %r', old_value, new_value)
         obj[self.udm_attribute_name] = new_value
 
     def hook_ldap_addlist(self, obj, al):
@@ -239,10 +239,10 @@ class AttributeHook(simpleHook):
                 else:
                     key, old_value, new_value = ml_value
                 if key == self.ldap_attribute_name:
-                    ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.AttributeHook: Mapping %s (UDM) -> %s (LDAP)' % (self.udm_attribute_name, self.ldap_attribute_name))
+                    log.debug('admin.syntax.hook.AttributeHook: Mapping %s (UDM) -> %s (LDAP)', self.udm_attribute_name, self.ldap_attribute_name)
                     old_value = self.map_attribute_value_to_ldap(old_value)
                     new_new_value = self.map_attribute_value_to_ldap(new_value)
-                    ud.debug(ud.ADMIN, ud.INFO, 'admin.syntax.hook.AttributeHook: Setting LDAP value from %r to %r' % (new_value, new_new_value))
+                    log.debug('admin.syntax.hook.AttributeHook: Setting LDAP value from %r to %r', new_value, new_new_value)
                     new_value = new_new_value
                 new_ml.append((key, old_value, new_value))
             return new_ml
