@@ -232,9 +232,10 @@ def init(lo, position, module, template_object=None, force_reload=False):
                 if subsyn.name == 'LDAP_Search':
                     subsyn._load(lo)
 
-    # add new properties
-    update_extended_options(lo, module, position)
-    update_extended_attributes(lo, module, position)
+    # add new properties, only for modules in default ldap base
+    if lo.compare_dn(configRegistry['ldap/base'].lower(), getattr(module.object, 'ldap_base', configRegistry['ldap/base']).lower()):
+        update_extended_options(lo, module, position)
+        update_extended_attributes(lo, module, position)
 
     # get defaults from template
     if template_object:
@@ -618,13 +619,13 @@ def update_extended_attributes(lo, module, position):
                 elif ea_layout.overwrite and not freshTab:  # we want to overwrite an existing property
                     # in the global fields ...
                     if not ea_layout.groupName:
-                        replaced, layout = currentTab.replace(ea_layout.overwrite, ea_layout.name, recursive=True)
+                        replaced, _layout = currentTab.replace(ea_layout.overwrite, ea_layout.name, recursive=True)
                         if not replaced:  # the property was not found so we'll append it
                             currentTab.layout.append(ea_layout.name)
                     else:
                         for item in currentTab.layout:
                             if isinstance(item, ILayoutElement) and item.label == ea_layout.groupName:
-                                replaced, layout = item.replace(ea_layout.overwrite, ea_layout.name)
+                                replaced, _layout = item.replace(ea_layout.overwrite, ea_layout.name)
                                 if not replaced:  # the property was not found so we'll append it
                                     item.layout.append(ea_layout.name)
                 else:
@@ -1138,7 +1139,7 @@ def defaultContainers(module):
     :param module: |UDM|
     :returns: a list of DNs.
     """
-    base = configRegistry['ldap/base']
+    base = getattr(module.object, 'ldap_base', configRegistry['ldap/base'])
     return ['%s,%s' % (rdn, base) for rdn in getattr(module, 'default_containers', [])]
 
 
