@@ -478,8 +478,6 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
     configRegistry = univention.config_registry.ConfigRegistry()
     configRegistry.load()
 
-    baseDN = configRegistry['ldap/base']
-
     debug_level = int(configRegistry.get('directory/manager/cmd/debug/level', 0))
 
     if logfile:
@@ -489,7 +487,7 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
 
     if not binddn or not bindpwd:
         for _binddn, secret_filename in (
-                ('cn=admin,' + baseDN, '/etc/ldap.secret'),
+                ('cn=admin,' + configRegistry['ldap/base'], '/etc/ldap.secret'),
                 (configRegistry['ldap/hostdn'], '/etc/machine.secret'),
         ):
             if os.path.exists(secret_filename):
@@ -505,22 +503,6 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
         policyOptions.extend(['-D', binddn, '-w', bindpwd])  # FIXME: not so nice
 
     log.debug("using %s account", binddn)
-    try:
-        lo = univention.admin.uldap.access(host=configRegistry['ldap/master'], port=int(configRegistry.get('ldap/master/port', '7389')), base=baseDN, binddn=binddn, start_tls=tls, bindpw=bindpwd)
-    except Exception as exc:
-        log.warning('authentication error: %s', exc)
-        raise OperationFailed('authentication error: %s' % (exc,))
-
-    if not position_dn and superordinate_dn:
-        position_dn = superordinate_dn
-    elif not position_dn:
-        position_dn = baseDN
-
-    try:
-        position = univention.admin.uldap.position(baseDN)
-        position.setDn(position_dn)
-    except univention.admin.uexceptions.noObject:
-        raise OperationFailed('E: Invalid position')
 
     module = univention.admin.modules.get(module_name)
     if not module:
@@ -529,6 +511,23 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
         list_available_modules(stderr)
         raise OperationFailed()
 
+    try:
+        lo = univention.admin.uldap.access(host=configRegistry['ldap/master'], port=int(configRegistry.get('ldap/master/port', '7389')), base=module.object.ldap_base, binddn=binddn, start_tls=tls, bindpw=bindpwd)
+    except Exception as exc:
+        log.warning('authentication error: %s', exc)
+        raise OperationFailed('authentication error: %s' % (exc,))
+
+    if not position_dn and superordinate_dn:
+        position_dn = superordinate_dn
+    elif not position_dn:
+        position_dn = module.object.ldap_base
+
+    try:
+        position = univention.admin.uldap.position(module.object.ldap_base)
+        position.setDn(position_dn)
+    except univention.admin.uexceptions.noObject:
+        raise OperationFailed('E: Invalid position')
+
     # initialise modules
     if module_name == 'settings/usertemplate':
         univention.admin.modules.init(lo, position, univention.admin.modules.get('users/user'))
@@ -557,7 +556,7 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
 
     for opt, val in opts:
         if opt == '--set':
-            name, delim, value = val.partition('=')
+            name, _delim, value = val.partition('=')
 
             for (properties, _options) in information.values():
                 if name in properties:
@@ -573,7 +572,7 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
             if name not in input:
                 print("WARNING: No attribute with name '%s' in this module, value not set." % name, file=stderr)
         elif opt == '--append':
-            name, delim, value = val.partition('=')
+            name, _delim, value = val.partition('=')
             for (properties, _options) in information.values():
                 if name in properties:
                     if not properties[name].cli_enabled:
@@ -588,7 +587,7 @@ def _doit(arglist, stdout=sys.stdout, stderr=sys.stderr):
                 print("WARNING: No attribute with name %s in this module, value not appended." % name, file=stderr)
 
         elif opt == '--remove':
-            name, delim, value = val.partition('=')
+            name, _delim, value = val.partition('=')
             value = value or None
             for (properties, _options) in information.values():
                 if name in properties:
@@ -797,7 +796,7 @@ class CLI(object):
             object.policy_reference(*policy_reference)
             object.policy_dereference(*policy_dereference)
 
-            if object.hasChanged(input.keys()) or object.hasChanged(append.keys()) or object.hasChanged(remove.keys()) or parsed_append_options or parsed_remove_options or parsed_options or object.policiesChanged():
+            if object.hasChanged(input.keys()) or object.hasChanged(append.keys()) or object.hasChanged(remove.keys()) or parsed_append_options or parsed_remove_options or parsed_options or object.policiesChanged():  # noqa: PLR0916
                 try:
                     dn = object.modify()
                     object_modified += 1
@@ -854,7 +853,6 @@ class CLI(object):
         try:
             for object in univention.admin.modules.lookup(module, None, lo, scope='sub', superordinate=superordinate, base=position.getDn(), filter=filter):
                 print('DN: %s' % univention.admin.objects.dn(object), file=self.stdout)
-
                 if not univention.admin.modules.virtual(module_name):
                     object.open()
                     for key, value in sorted(object.items()):
