@@ -41,6 +41,7 @@ import copy
 import functools
 import inspect
 import logging
+import operator
 import sys
 
 import ldap
@@ -340,7 +341,7 @@ class GenericObject(BaseObject):
         """
         self._orig_udm_object.options = self.options
         if self._udm_module.meta.used_api_version >= 3:
-            self._orig_udm_object.policies = functools.reduce(lambda x, y: x + y, self.policies.values(), [])
+            self._orig_udm_object.policies = functools.reduce(operator.add, self.policies.values(), [])
         else:
             self._orig_udm_object.policies = self.policies
         self._orig_udm_object.position.setDn(self.position)
@@ -634,7 +635,7 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
         :rtype: list(str)
         """
         module_contailers = [
-            '{},{}'.format(dc, ucr['ldap/base'])
+            '{},{}'.format(dc, getattr(self._orig_udm_module.object, 'ldap_base', ucr['ldap/base']))
             for dc in getattr(self._orig_udm_module, 'default_containers', [])
         ]
 
@@ -644,7 +645,7 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
         if default_containers and default_positions_property:
             dns = default_containers.get(default_positions_property, [])
             module_contailers.extend(dn for dn in dns if self._dn_exists(dn))
-        module_contailers.append(self.connection.base)
+        module_contailers.append(getattr(self._orig_udm_module.object, 'ldap_base', self.connection.base))
         return module_contailers
 
     def _get_orig_udm_module(self):
@@ -704,7 +705,7 @@ class GenericModule(with_metaclass(GenericModuleMeta, BaseModule)):
             superordinate_modules = univention.admin.modules.superordinate_names(self.name)
             if superordinate_modules and superordinate_modules != ['settings/cn']:
                 raise NoSuperordinate(dn=dn, module_name=self.name, superordinate_types=superordinate_modules)
-        po = univention.admin.uldap.position(self.connection.base)
+        po = univention.admin.uldap.position(getattr(udm_module.object, 'ldap_base', self.connection.base))
         try:
             obj = univention.admin.objects.get(udm_module, None, self.connection, po, dn=dn, superordinate=superordinate_obj)
         except univention.admin.uexceptions.noObject:
